@@ -53,6 +53,8 @@ static void catchXShmError(Display * , XErrorEvent * )
 }
 #endif
 
+std::set <XvPortID> XVWindow::grabbedPorts;
+
 XVWindow::XVWindow()
 {
   // initialize class variables
@@ -100,6 +102,7 @@ XVWindow::~XVWindow()
   if (_XVPort) {
 
     XvUngrabPort (_display, _XVPort, CurrentTime);
+    grabbedPorts.erase(_XVPort);
     _XVPort = 0;
   }
 
@@ -220,7 +223,6 @@ XVWindow::Init (Display* dp,
     _XVImage[i]->data = (char*) malloc(_XVImage[i]->data_size);
   }
 
-    XSync(_display, False);
     PTRACE(1, "XVideo\tNot using SHM extension");
 #ifdef HAVE_SHM
   }
@@ -229,6 +231,7 @@ XVWindow::Init (Display* dp,
   }
 #endif
 
+  XSync(_display, False);
 
   _isInitialized = true;
   XUnlockDisplay (_display);
@@ -400,6 +403,12 @@ XVWindow::FindXVPort ()
 
       for (candidateXVPort = xvainfo [i].base_id ; candidateXVPort < (xvainfo [i].base_id + xvainfo [i].num_ports) ; ++candidateXVPort) {
 
+        if (grabbedPorts.find(candidateXVPort) != grabbedPorts.end()) {
+          PTRACE(4, "XVideo\tPort " << candidateXVPort << " already grabbed by ourselves");
+          ++busyPorts;
+          continue;
+        }
+
         if (PTrace::CanTrace (4)) 
           DumpCapabilities (candidateXVPort);
 
@@ -425,7 +434,8 @@ XVWindow::FindXVPort ()
 
             PTRACE(4, "XVideo\tGrabbed Port: " << candidateXVPort);
             XvFreeAdaptorInfo (xvainfo);
-
+            grabbedPorts.insert(candidateXVPort);
+            
             return candidateXVPort;
           } 
           else {
