@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -43,66 +43,13 @@
 #include "common.h"
 
 
-
-/* DESCRIPTION  :  This callback is called when the user chooses to save.
- * BEHAVIOR     :  Saves the picture in the current video stream in a file.
- * PRE          :  /
- */
-void save_callback (GtkWidget *,
-		    gpointer);
-
-
-/* DESCRIPTION  :  This callback is called when the user chooses to open
- *                 the about window.
- * BEHAVIOR     :  Open the about window.
- * PRE          :  /
- */
-void about_callback (GtkWidget *,
-		     gpointer);
-
-
-/* DESCRIPTION  :  This callback is called when the user chooses to open
- *                 the help window.
- * BEHAVIOR     :  Open the help window.
- * PRE          :  /
- */
-void help_cb (GtkWidget *,
-              gpointer);
-
-
-/* DESCRIPTION  :  This callback is called when the user choose to establish
- *                 a connection.
- * BEHAVIOR     :  Call the remote endpoint or accept the incoming call.
- * PRE          :  /
- */
-void connect_cb (GtkWidget *,
-		 gpointer);
-
-
-/* DESCRIPTION  :  This callback is called when the user choose to stop
- *                 a connection.
- * BEHAVIOR     :  Do not accept the incoming call or stops the current call.
- * PRE          :  /
- */
-void disconnect_cb (GtkWidget *,
-		    gpointer);
-
-
-/* DESCRIPTION  :  This callback is called when the user chooses to quit.
- * BEHAVIOR     :  Quit.
- * PRE          :  /
- */
-void quit_callback (GtkWidget *,
-		    gpointer);
-
-
 /* DESCRIPTION  :  Simple wrapper that will call gnomemeeting_hide_window.
  * BEHAVIOR     :  Calls gnomemeeting_window_hide.
  * PRE          :  /
  */
-gboolean delete_window_cb (GtkWidget *,
-                           GdkEvent *,
-                           gpointer);
+gboolean delete_window_cb (GtkWidget *widget,
+                           GdkEvent *event,
+                           gpointer data);
 
 
 /* DESCRIPTION  :  Simple wrapper that will call gnomemeeting_show_window.
@@ -111,43 +58,48 @@ gboolean delete_window_cb (GtkWidget *,
  * PRE          :  The gpointer is a valid pointer to the GtkWindow that needs
  *                 to be shown with the correct size and position.
  */
-void show_window_cb (GtkWidget *,
-		     gpointer);
+void show_window_cb (GtkWidget *widget,
+		     gpointer data);
 
+void show_assistant_window_cb (GtkWidget *widget,
+                               gpointer   data);
+
+void show_prefs_window_cb (GtkWidget *widget,
+			   gpointer   data);
 
 /* DESCRIPTION  :  Simple wrapper that will call gnomemeeting_window_hide.
  * BEHAVIOR     :  Calls gnomemeeting_window_hide.
  * PRE          :  The gpointer is a valid pointer to the GtkWindow that needs
  *                 to be shown with the correct size and position.
  */
-void hide_window_cb (GtkWidget *,
-		     gpointer);
+void hide_window_cb (GtkWidget *widget,
+		     gpointer data);
 
 
-/* DESCRIPTION  :  Quit callback.
- * BEHAVIOR     :  Disconnects, then simply call gtk_main_quit.
+/* DESCRIPTION  :  This callback is called when the user chooses to open
+ *                 the about window.
+ * BEHAVIOR     :  Open the about window.
  * PRE          :  /
  */
-void gtk_main_quit_callback (int,
-			     gpointer);
+void about_callback (GtkWidget *widget,
+		     gpointer parent_window);
 
 
-/* DESCRIPTION  :  This callback is called to compare urls and see if they
- * 		   match.
- * BEHAVIOR     :  It returns TRUE if the given key matches an URL OR a last
- * 		   name or first name in the list store of the completion 
- * 		   entry AND if the matched URL was not already returned
- * 		   previously.
- * 		   2 SIP/H323 URLs match if they begin by
- * 		   the same chars, and 2 CALLTO URLs with a valid email
- * 		   address on an ILS server match if the key matches an email
- * 		   address or the begin of a server. 
- * PRE          :  data is a valid pointer to the list store.
+/* DESCRIPTION  :  This callback is called when the user chooses to open
+ *                 the help window.
+ * BEHAVIOR     :  Open the help window.
+ * PRE          :  /
  */
-gboolean entry_completion_url_match_cb (GtkEntryCompletion *,
-					const gchar *,
-					GtkTreeIter *,
-					gpointer);
+void help_cb (GtkWidget *widget,
+              gpointer data);
+
+
+/* DESCRIPTION  :  This callback is called when the user chooses to quit.
+ * BEHAVIOR     :  Quit.
+ * PRE          :  /
+ */
+void quit_callback (GtkWidget *widget,
+		    gpointer data);
 
 
 /* DESCRIPTION  :  This callback is called when the user toggles a
@@ -158,6 +110,8 @@ gboolean entry_completion_url_match_cb (GtkEntryCompletion *,
  * 		   if the endpoint calling state is not Standby.
  * PRE          :  data is a valid pointer to the URL GtkEntry.
  */
-void connect_button_clicked_cb (GtkToggleButton *, 
-				gpointer);
+void connect_button_clicked_cb (GtkToggleButton *widget,
+				gpointer data);
+
+
 #endif
