@@ -39,8 +39,13 @@
 #ifndef _MAIN_INTERFACE_H
 #define _MAIN_INTERFACE_H
 
+#include "config.h"
+
 #include "common.h"
 
+#include "services.h"
+#include "call.h"
+
 
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Press the given dialpad key.
@@ -51,44 +56,32 @@ void gm_main_window_press_dialpad (GtkWidget *main_window,
 
 
 /* DESCRIPTION  :  /
- * BEHAVIOR     :  Updates the video area in the main window/local or remote
- * 		   popup with the given RGB buffer and the given destination
- * 		   size. The correct video area is udpated given the current
- * 		   display mode and if the given buffer is a buffer for local
- * 		   or remote video.
- * PRE          :  The main window GMObject, a valid RGB32 buffer, its width
- * 		   and height, the zoomed width and height, the display mode
- * 		   (see gdkvideoio.cpp), and if the given buffer is a remote
- * 		   or local video image. The last parameter indicates if
- * 		   there should be bilinear filtering or not.
+ * BEHAVIOR     :  Return the video widget in which we can display.
+ * PRE          :  The main window GMObject.
  */
-void gm_main_window_update_video (GtkWidget *main_window,
-				  const guchar *lbuffer,
-				  int lf_width,
-				  int lf_height,
-				  double lzoom,
-				  const guchar *rbuffer,
-				  int rf_width,
-				  int rf_height,
-				  double rzoom,
-				  int display_type,
-				  gboolean bilinear_filtering);
+GtkWidget *gm_main_window_get_video_widget (GtkWidget *main_window);
 
 
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Displays the gnomemeeting logo in the video window.
  * PRE          :  The main window GMObject.
  */
-void gm_main_window_update_logo (GtkWidget *main_window);
+void gm_main_window_update_logo_have_window (GtkWidget *main_window);
 
 
+/* DESCRIPTION  :  /
+ * BEHAVIOR     :  Displays the gnomemeeting logo in the video window.
+ * PRE          :  /
+ */
+void gm_main_window_update_logo ();
+
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Update the main window hold call menu and toolbar items
  * 		   following the call is on hold (TRUE) or not (FALSE).
  * PRE          :  The main window GMObject.
  */
 void gm_main_window_set_call_hold (GtkWidget *main_window,
-				   gboolean is_on_hold);
+                                   bool is_on_hold);
 
 
 /* DESCRIPTION  :  /
@@ -123,22 +116,6 @@ void gm_main_window_update_calling_state (GtkWidget *main_window,
 					  unsigned calling_state);
 
 
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Update the main window sensitivity following the opened
- *                 and closed audio and video channels. It also updates
- *                 the state of the video preview button.
- * PRE          :  The main window GMObject.
- * 		   The first parameter is TRUE if we are updating video
- *                 channels related items, FALSE if we are updating audio
- *                 channels related items. The second parameter is TRUE
- *                 if we are transmitting audio (or video), the third is TRUE
- *                 if we are receiving audio (or video).
- */
-void gm_main_window_update_sensitivity (GtkWidget *main_window,
-					BOOL is_video,
-					BOOL is_receiving,
-					BOOL is_transmitting);
-
 
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Update the main window busy state. When the window is busy,
@@ -147,7 +124,7 @@ void gm_main_window_update_sensitivity (GtkWidget *main_window,
  * 		   The first parameter is TRUE if we are busy.
  */
 void gm_main_window_set_busy (GtkWidget *main_window,
-			      BOOL busy);
+			      bool busy);
 
 
 /* DESCRIPTION  :  /
@@ -163,23 +140,6 @@ void gm_main_window_set_volume_sliders_values (GtkWidget *main_window,
 					       int input_volume);
 
 
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Update the main window signal level meters.
- * PRE          :  A valid pointer to the main window GMObject, followed
- * 		   by the output and input signals.
- */
-void gm_main_window_set_signal_levels (GtkWidget *main_window,
-				       float output,
-				       float input);
-
-
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Clear the main window signal level meters.
- * PRE          :  /
- */
-void gm_main_window_clear_signal_levels (GtkWidget *main_window);
-
-
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Gets the values of the main window audio sliders.
  * PRE          :  A valid pointer to the main window GMObject, followed
@@ -225,28 +185,21 @@ void gm_main_window_get_video_sliders_values (GtkWidget *main_window,
 
 
 /* DESCRIPTION  :  /
- * BEHAVIOR     :  Change the view mode and update the menu.
- * PRE          :  The main window GMObject and a valid mode.
- */
-void gm_main_window_set_view_mode (GtkWidget *main_window,
-				   ViewMode m);
-
-
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Select the correct control panel section in the menus
+ * BEHAVIOR     :  Select the correct panel section in the menus
  * 		   and in the main window.
  * PRE          :  The main window GMObject and a valid section.
  */
-void gm_main_window_set_control_panel_section (GtkWidget *main_window,
-					       int section);
+void gm_main_window_set_panel_section (GtkWidget *main_window,
+                                       int section);
 
 
 /* DESCRIPTION  :  /
- * BEHAVIOR     :  Select the incoming call mode for the main window.
+ * BEHAVIOR     :  Set the status for the main window.
  * PRE          :  The main window GMObject and a valid incoming call mode.
  */
-void gm_main_window_set_incoming_call_mode (GtkWidget *main_window,
-					    IncomingCallMode i);
+void gm_main_window_set_status (GtkWidget *main_window,
+                                std::string short_status,
+                                std::string long_status);
 
 
 /* DESCRIPTION  :  /
@@ -265,14 +218,12 @@ void gm_main_window_set_call_info (GtkWidget *main_window,
 				   const char *re_video_codec);
 
 
-/* DESCRIPTION  :  /
- * BEHAVIOR     :  Updates the information displayed in the info label
- * 		   of the main window.
- * PRE          :  The main window GMObject, 
- * 		   the number of "online" accounts.
+/* DESCRIPTION   :  /
+ * BEHAVIOR      : Sets the current call duration (as a string) in the GUI.
+ * PRE           : The main window GMObject.
  */
-void gm_main_window_set_account_info (GtkWidget *main_window,
-				      int registered_account);
+void gm_main_window_set_call_duration (GtkWidget *main_window,
+                                       const char *duration);
 
 
 /* DESCRIPTION   :  /
@@ -312,23 +263,11 @@ gboolean gm_main_window_transfer_dialog_run (GtkWidget *main_window,
 					     const char *u);
 
 
-/* DESCRIPTION   :  /
- * BEHAVIOR      : Creates a new incoming call popup and show it 
- * 		   as modal dialog.
- * PRE           : The main window GMObject.
- * 		   The name and the app in UTF-8 char * and the remote URL
- */
-void gm_main_window_incoming_call_dialog_show (GtkWidget *main_window,
-					       gchar *utf8_name,
-					       gchar *utf8_app,
-					       gchar *utf8_url);
-
-
 /* DESCRIPTION  :  /
  * BEHAVIOR     :  Builds the main window and adds the popup to the image.
  * PRE          :  Accels.
- **/
-GtkWidget *gm_main_window_new ();
+ */
+GtkWidget *gm_main_window_new (Ekiga::ServiceCore & core);
 
 
 /* DESCRIPTION   :  /
@@ -348,8 +287,8 @@ void gm_main_window_flash_message (GtkWidget *main_window,
  * 		   calls and the number of voice mails.
  */
 void gm_main_window_push_message (GtkWidget *main_window,
-				  int missed,
-				  const char *vm);
+				  unsigned int missed,
+				  unsigned int mwi);
 
 
 /* DESCRIPTION   :  /
@@ -416,7 +355,11 @@ void gm_main_window_update_stats (GtkWidget *main_window,
 				  float new_video_octets_received,
 				  float new_video_octets_transmitted,
 				  float new_audio_octets_received,
-				  float new_audio_octets_transmitted);
+				  float new_audio_octets_transmitted,
+				  unsigned int re_width,
+				  unsigned int re_height,
+				  unsigned int tr_width,
+				  unsigned int tr_height);
 
 
 /* DESCRIPTION   :  /
@@ -432,7 +375,30 @@ GdkPixbuf *gm_main_window_get_current_picture (GtkWidget *main_window);
  */
 void gm_main_window_set_stay_on_top (GtkWidget *main_window,
 				     gboolean stay_on_top);
- 
+
+
+/* DESCRIPTION  :  /
+ * BEHAVIOR     :  Update the main window sensitivity following the opened
+ *                 and closed audio and video channels. It also updates
+ *                 the state of the video preview button.
+ * PRE          :  The main window GMObject.
+ * 		   The first parameter is TRUE if we are updating video
+ *                 channels related items, FALSE if we are updating audio
+ *                 channels related items. The second parameter is TRUE
+ *                 if we are transmitting audio (or video), the third is TRUE
+ *                 if we are receiving audio (or video).
+ */
+void gm_main_window_update_sensitivity (GtkWidget *main_window,
+					bool is_video,
+					bool is_receiving,
+					bool is_transmitting);
+
+
+/* DESCRIPTION   :  /
+ * BEHAVIOR      : Updates the menu sensitivity
+ * PRE           : The main window GMObject.
+ */
+void gm_main_window_fullscreen_menu_update_sensitivity (bool fullscreen);
 
 #endif
 
