@@ -52,13 +52,6 @@
 #include <sigc++/sigc++.h>
 #include <vector>
 
-#ifdef HAVE_GNOME
-#undef _
-#undef N_
-#include <gnome.h>
-#include <libbonobo.h>
-#endif
-
 #include "services.h"
 #include "gtk-frontend.h"
 #include "personal-details.h"
@@ -184,7 +177,7 @@ statusicon_finalize (GObject *obj)
        iter++)
     iter->disconnect ();
 
-  g_free (self->priv);
+  delete self->priv;
 
   parent_class->finalize (obj);
 }
@@ -269,10 +262,17 @@ statusicon_activated_cb (G_GNUC_UNUSED GtkStatusIcon *icon,
     window = GnomeMeeting::Process ()->GetMainWindow (); //FIXME
 
     // FIXME when the main window becomes a gobject
-    if (!gnomemeeting_window_is_visible (window))
-      gnomemeeting_window_show (window);
-    else
-      gnomemeeting_window_hide (window);
+    if (!(GTK_WIDGET_VISIBLE (window) 
+          && !(gdk_window_get_state (GDK_WINDOW (window->window)) & GDK_WINDOW_STATE_ICONIFIED))) {
+      gtk_widget_show (window);
+    }
+    else {
+
+      if (gtk_window_has_toplevel_focus (GTK_WINDOW (window)))
+        gtk_widget_hide (window);
+      else
+        gtk_window_present (GTK_WINDOW (window));
+    }
   }
   else {
 
@@ -391,7 +391,6 @@ statusicon_build_menu ()
 
   static MenuEntry menu [] =
     {
-#ifdef HAVE_GNOME
       GTK_MENU_ENTRY("help", NULL,
                      _("Get help by reading the Ekiga manual"),
                      GTK_STOCK_HELP, GDK_F1,
@@ -399,21 +398,10 @@ statusicon_build_menu ()
 
       GTK_MENU_ENTRY("about", NULL,
 		     _("View information about Ekiga"),
-		     GNOME_STOCK_ABOUT, 'a',
+		     GTK_STOCK_ABOUT, 0,
 		     GTK_SIGNAL_FUNC (about_callback), (gpointer) main_window,
 		     TRUE),
-#else
-      GTK_MENU_ENTRY("help", _("_Contents"),
-                     _("Get help by reading the Ekiga manual"),
-                     GTK_STOCK_HELP, GDK_F1,
-                     NULL, NULL, FALSE),
 
-      GTK_MENU_ENTRY("about", _("_About"),
-		     _("View information about Ekiga"),
-		     NULL, 'a',
-		     GTK_SIGNAL_FUNC (about_callback), (gpointer) main_window,
-		     TRUE),
-#endif
       GTK_MENU_SEPARATOR,
 
       GTK_MENU_ENTRY("quit", NULL, _("Quit"),
